
a, a:hover, a:focus {
    color: black;
}

.black{
  color: black;
}

.background_gray{
  background: #F8F8F8;
  border-color: #E7E7E7;
  border: 2px solid #E7E7E7;
}

.item-panel{
  padding: 10px;
  border: 1px solid #DDD;
  border-radius: 0px;
  list-style-type: none;
}

.without-style-list{
  list-style-type: none;
}

.item-notification{
  width: 35em;
  text-transform: none;
}

.without-text-transform{
  text-transform: none;
}

.btn{
  text-transform: none;
}

/* Hide element */
.hide{
  display: none;
}

/*
  Margin left for buttons join and unregister forum
*/
.margin-left-unregister{
  margin-left: 2em;
}

@media screen and (min-width:1280px) {
  @-moz-document url-prefix() {
    .margin-left-moz{
      margin-left: 0.3em;
    }
  }
}

/* enable absolute positioning for within text box icon*/
.inner-addon {
    position: relative;
}

/* style icon */
.inner-addon .glyphicon {
  position: absolute;
  padding: 10px;
  pointer-events: none;
}

/* align icon */
.left-addon .glyphicon  { left:  0px;}
.right-addon .glyphicon { right: 0px;}

/* add padding  */
.left-addon input  { padding-left:  30px; }
.right-addon input { padding-right: 30px; }

/* For that not outside textarea in div*/
.in_div_textarea{
  overflow: auto;
}
