{% load i18n %}
{% load endless %}
{% load forum_tags %}

<div class="list-group">
	{% paginate notifications  %}
	{% for notification in notifications %}
	    {% if notification.is_view %}
			{{notification|get_item_notification|safe}}
	    {% else %}
			{{notification|get_item_notification|safe}}
	    {% endif %}
	{% empty %}
		<p class="text-info">{% trans "No results" %}.</p>
    {% endfor %}
	{% show_more %}
</div>