{% load i18n %}
{% load static %}
{% load photo %}
{% load forum_tags %}
{% load endless %}

{% paginate registers %}
{% for profile in registers %}
    <div class="col-sm-2">
        <div>
            <div class="avatar">
                <img src="{{profile.user.id|get_photo}}" class="img-thumbnail picture" width="100" hegiht="100" />
            </div>
            <div class="content">
                <br>
                <span>{{ profile.user|get_path_profile|safe }}</span>
                <br>
                <p>{{profile.date}}</p>
            </div>
        </div>
    </div>
{% empty %}
    <small class="text-info">{% trans "No registered users" %}.</small>
{% endfor %}
{% show_more %}
